# Changelog

## [2.1.0a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/2.1.0a1) (2024-11-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.0.1...2.1.0a1)

**Merged pull requests:**

- feat: status [\#266](https://github.com/OpenVoiceOS/OVOS-workshop/pull/266) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
